atomdb module
=============

This modules is designed to interact with the main atomic database, extracting real values of coefficients and so on.

.. automodule:: pyatomdb.atomdb
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:
